==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ManagedClusterStorageProfileFileCSIDriverArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ManagedClusterStorageProfileFileCSIDriverArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * AzureFile CSI Driver settings for the storage profile.
 * @property enabled Whether to enable AzureFile CSI Driver. The default value is true.
 */
public data class ManagedClusterStorageProfileFileCSIDriverArgs(
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ManagedClusterStorageProfileFileCSIDriverArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterStorageProfileFileCSIDriverArgs =
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterStorageProfileFileCSIDriverArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ManagedClusterStorageProfileFileCSIDriverArgs].
 */
@PulumiTagMarker
public class ManagedClusterStorageProfileFileCSIDriverArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    /**
     * @param value Whether to enable AzureFile CSI Driver. The default value is true.
     */
    @JvmName("lnwevmdfiihshojx")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Whether to enable AzureFile CSI Driver. The default value is true.
     */
    @JvmName("yfikkqytyjmgigcx")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): ManagedClusterStorageProfileFileCSIDriverArgs =
        ManagedClusterStorageProfileFileCSIDriverArgs(
            enabled = enabled,
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/containerservice/kotlin/inputs/ManagedClusterStorageProfileFileCSIDriverArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.containerservice.kotlin.inputs

import com.pulumi.azurenative.containerservice.inputs.ManagedClusterStorageProfileFileCSIDriverArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * AzureFile CSI Driver settings for the storage profile.
 * @property enabled Whether to enable AzureFile CSI Driver. The default value is true.
 */
public data class ManagedClusterStorageProfileFileCSIDriverArgs(
    public val enabled: Output<Boolean>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.containerservice.inputs.ManagedClusterStorageProfileFileCSIDriverArgs> {
    override fun toJava():
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterStorageProfileFileCSIDriverArgs =
        com.pulumi.azurenative.containerservice.inputs.ManagedClusterStorageProfileFileCSIDriverArgs.builder()
            .enabled(enabled?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ManagedClusterStorageProfileFileCSIDriverArgs].
 */
@PulumiTagMarker
public class ManagedClusterStorageProfileFileCSIDriverArgsBuilder internal constructor() {
    private var enabled: Output<Boolean>? = null

    /**
     * @param value Whether to enable AzureFile CSI Driver. The default value is true.
     */
    @JvmName("kkinafvaqijmpnsj")
    public suspend fun enabled(`value`: Output<Boolean>) {
        this.enabled = value
    }

    /**
     * @param value Whether to enable AzureFile CSI Driver. The default value is true.
     */
    @JvmName("wjirhscfusehtxoa")
    public suspend fun enabled(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.enabled = mapped
    }

    internal fun build(): ManagedClusterStorageProfileFileCSIDriverArgs =
        ManagedClusterStorageProfileFileCSIDriverArgs(
            enabled = enabled,
        )
}
